This function performs Monte Carlo simulations when needed, it is not developed for the use of the user.
.MonteCarlo(
statistic,
alternative,
FUN,
B = 1000,
rdist = stats::runif,
Trows,
Mcols,
...
)Observed value of the statistic.
A character string indicating the alternative hypothesis
and must be one of "greater", "less" or "two.sided".
A function that computes the statistic.
An integer specifying the number of replicates used in the Monte Carlo approach.
Number of rows and columns respectively, of the desired
sample rdist.
Not used.
Estimated p-value.